## ----setup, include = FALSE-------------------------------------------------------------------------------------------
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>",
    crop = NULL, ## Related to https://stat.ethz.ch/pipermail/bioc-devel/2020-April/016656.html
    dpi = 900,
    out.width = "100%",
    message = FALSE,
    warning = FALSE,
    fig.width = 10,
    fig.height = 6
)


chevreul_sce <- chevreuldata::human_gene_transcript_sce()

## ----packages---------------------------------------------------------------------------------------------------------
library(chevreul)
library(scater)
library(scran)
library(tidyverse)
library(ggraph)
library(patchwork)

## ---------------------------------------------------------------------------------------------------------------------
plot_feature(chevreul_sce,
    embedding = "UMAP",
    features = "NRL", return_plotly = FALSE
)

## ---------------------------------------------------------------------------------------------------------------------
plot_readcount(chevreul_sce,
    group_by = "nCount_RNA",
    color.by = "Prep.Method"
)

## ---------------------------------------------------------------------------------------------------------------------
plot_var(chevreul_sce,
    group = "gene_snn_res.0.2",
    embedding = "UMAP"
)

## ---------------------------------------------------------------------------------------------------------------------
plot_markers(chevreul_sce,
    group_by = "gene_snn_res.0.2",
    marker_method = "wilcox"
)

## ---------------------------------------------------------------------------------------------------------------------
plot_violin(chevreul_sce, plot_var = "Kit_ID", features = "NRL")

## ---------------------------------------------------------------------------------------------------------------------
plot_all_transcripts(chevreul_sce, features = "NRL")

## ----results=FALSE, echo=FALSE----------------------------------------------------------------------------------------
data("grch38")
data("grch38_tx2gene")
plot_transcript_composition(chevreul_sce, "NRL",
    group.by = "gene_snn_res.0.2", standardize = TRUE
)

## ---------------------------------------------------------------------------------------------------------------------
top_10_features <- getTopHVGs(chevreul_sce)[1:10]

make_complex_heatmap(chevreul_sce,
    features = top_10_features,
    group.by = "gene_snn_res.0.2"
)

make_complex_heatmap(chevreul_sce,
    features = top_10_features,
    group.by = "gene_snn_res.0.2", col_arrangement = "average"
)

make_complex_heatmap(chevreul_sce,
    features = top_10_features,
    group.by = c("Prep.Method", "gene_snn_res.0.2"),
    col_arrangement = "gene_snn_res.0.2"
)

## ----reproduce3, echo=FALSE-------------------------------------------------------------------------------------------
## Session info
library("sessioninfo")
options(width = 120)
session_info()

